# Section

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus vel metus sapien. Vivamus pharetra at metus nec semper. 

## Subsection

Aliquam feugiat egestas libero luctus fermentum. 

### Subsubsection

Sed rutrum sed ligula et interdum. Vestibulum sollicitudin pellentesque fermentum. 

#* Unnumbered section

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus vel metus sapien. Vivamus pharetra at metus nec semper. 

##* Unnumbered subsection

Aliquam feugiat egestas libero luctus fermentum. 

###* Unnumbered subsubsection

Sed rutrum sed ligula et interdum. Vestibulum sollicitudin pellentesque fermentum. 

# No empty line section
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus vel metus sapien. Vivamus pharetra at metus nec semper. 
## No empty line subsection
Aliquam feugiat egestas libero luctus fermentum. 
### No empty line subsubsection
Sed rutrum sed ligula et interdum. Vestibulum sollicitudin pellentesque fermentum.

#* No empty line unnumbered section
Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus vel metus sapien. Vivamus pharetra at metus nec semper. 
##* No empty line unnumbered subsection
Aliquam feugiat egestas libero luctus fermentum. 
###* No empty line unnumbered subsubsection
Sed rutrum sed ligula et interdum. Vestibulum sollicitudin pellentesque fermentum.